Class: Ncn::Command::Help
Constant Summary collapse
- HELP =
"Usage:\n\ncreate - generate new note and open it with the $EDITOR\nopen - open one or multiple notes as a single draft\nhelp - list all commands or display detailed help for a specific command\n\nCommon options:\n\n--help - similar to the help command\n--path - repository directory path (default is \"notes\" in the current directory)\n"
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
Constructor Details
This class inherits a constructor from Ncn::Command::Base
Instance Method Details
#perform ⇒ Object
17 18 19 |
# File 'lib/ncn/command/help.rb', line 17 def perform puts HELP end |